Crate autopilot

autopilot is a simple, cross-platform GUI automation library for Rust.

Modules

  • This module contains functions for displaying alerts.
  • This module defines the struct Bitmap for accessing bitmaps and searching for bitmaps on-screen.
  • This module contains functions for controlling the keyboard.
  • This module contains functions for getting the current state of and controlling the mouse cursor.
  • This module contains functions for working with the screen.